APTOS_COIN_TYPE = "0x1::aptos_coin::AptosCoin"
APTOS_COIN_DECIMALS = 8

LAYERZERO_USD_COIN_TYPE = "0xf22bede237a07e121b56d91a491eb7bcdfd1f5907926a9e58338f964a01b17fa::asset::USDC"
LAYERZERO_USD_COIN_DECIMALS = 6

DITTO_STAKED_APTOS_COIN_TYPE = "0xd11107bdf0d6d7040c6c0bfbdecb6545191fdf13e8d8d259952f53e1713f61b5::staked_coin::StakedAptos"
DITTO_STAKED_APTOS_COIN_DECIMALS = 8

TORTUGA_STAKED_APT_COIN_TYPE = (
    "0x84d7aeef42d38a5ffc3ccef853e1b82e4958659d16a7de736a29c55fbbeb0114::staked_aptos_coin::StakedAptosCoin"
)
TORTUGA_STAKED_APT_COIN_DECIMALS = 8
